@@ -2,21 +2,21 @@
 #
 # Module   : CTK::DBI
 # Style    : OOP
-# DATE     : 03.03.2013
-# Revision : $Revision: 180 $
-# Id       : $Id: DBI.pm 180 2014-04-14 19:59:32Z minus $
+# DATE     : 12.05.2015
+# Revision : $Revision: 184 $
+# Id       : $Id: DBI.pm 184 2015-05-12 10:15:56Z minus $
 #
 #        DBI.        
 #   multistore   MPMinus
 #
 #       : Sys::SigAction
 #
-# Copyright (c) 1998-2012 D&D Corporation. All rights reserved
-# Copyright (C) 1998-2012 Lepenkov Sergej (Serz Minus) <minus@mail333.com>
+# Copyright (c) 1998-2015 D&D Corporation. All rights reserved
+# Copyright (C) 1998-2015 Lepenkov Sergej (Serz Minus) <minus@mail333.com>
 #
 #
 ################################################
-package CTK::DBI; # $Id: DBI.pm 180 2014-04-14 19:59:32Z minus $
+package CTK::DBI; # $Id: DBI.pm 184 2015-05-12 10:15:56Z minus $
 use strict;
 
 =head1 NAME
@@ -25,15 +25,18 @@ CTK::DBI - Database independent interface for CTKlib
 
 =head1 VERSION
 
-Version 2.25
+Version 2.26
 
 =head1 REVISION
 
-$Revision: 180 $
+$Revision: 184 $
 
 =head1 SYNOPSIS
 
     use CTK::DBI;
+    
+    # Enable debugging
+    # $CTK::DBI::CTK_DBI_DEBUG = 1;
 
     # MySQL connect
     my $mso = new CTK::DBI(
@@ -97,8 +100,9 @@ use constant {
     TIMEOUT_REQUEST => 60, # timeout request
 };
 
+our $CTK_DBI_DEBUG = 0;
 use vars qw/$VERSION/;
-$VERSION = '2.25';
+$VERSION = '2.26';
 
 my $LOAD_SigAction = 0;
 eval 'use Sys::SigAction';
@@ -347,7 +351,8 @@ sub DBI_EXECUTE {
     my @inargs = ();
     @inargs = @_ if exists $_[0];
     my $argb = "";
-    $argb = "Params: ".join(", ", @inargs) if exists $inargs[0];
+    my @repsrgs = @inargs;
+    $argb = sprintf("Params: %s", join(", ", map {defined $_ ? sprintf("\"%s\"",$_) : 'undef'} @repsrgs)) if exists $inargs[0];
     
     my $sth_ex = $dbh->prepare($sql);
     unless ($sth_ex) {
@@ -383,6 +388,6 @@ sub DBI_EXECUTE {
     
     return $sth_ex || undef;
 }
-sub _debug { 1 }
+sub _debug { $CTK_DBI_DEBUG ? carp(@_) : 1 }
 sub _error { carp(@_) }
 1;
\ No newline at end of file
