@@ -1,11 +1,11 @@
-package CTK::Helper::SkelModule; # $Id: SkelModule.pm 169 2013-10-18 11:37:18Z minus $
+package CTK::Helper::SkelModule; # $Id: SkelModule.pm 184 2015-05-12 10:15:56Z minus $
 use strict;
 
 use CTKx;
 use CTK::Util qw/ :BASE /;
 
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 sub build {
     #  
@@ -205,7 +205,7 @@ Your Name (Your Nickname) L<http://your.site> E<lt>your@email.comE<gt>
 
 %PODSIG%head1 COPYRIGHT
 
-Copyright (C) 1998-2013 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2015 D&D Corporation. All Rights Reserved
 
 %PODSIG%head1 LICENSE
 
@@ -298,6 +298,8 @@ my $code = __PACKAGE__->can(uc($command)) || __PACKAGE__->can($command);
 if ($code && ref($code) eq 'CODE') {
     %cmddata = %{CMD->{$command}};
     $cmddata{arguments} = [@arguments];
+
+    CTK::preparedir({ datadir => $c->datadir() });
     
     #  LOG    
     $c->logfile(CTK::catfile($c->logdir(), 
@@ -358,7 +360,7 @@ Name: FakeCTK.pm
 File: %PROJECTNAME%/inc/FakeCTK.pm
 Mode: 644
 
-package FakeCTK; # $Id: SkelModule.pm 169 2013-10-18 11:37:18Z minus $
+package FakeCTK; # $Id: SkelModule.pm 184 2015-05-12 10:15:56Z minus $
 use strict;
 
 %PODSIG%head1 NAME
@@ -409,7 +411,7 @@ Name: PostConf.pm
 File: %PROJECTNAME%/inc/PostConf.pm
 Mode: 644
 
-package PostConf; # $Id: SkelModule.pm 169 2013-10-18 11:37:18Z minus $
+package PostConf; # $Id: SkelModule.pm 184 2015-05-12 10:15:56Z minus $
 use strict;
 
 %PODSIG%head1 NAME
